[![PyPI - Version](https://img.shields.io/pypi/v/loam)](https://pypi.org/project/loam/)

loam
====

The main goal of loam is to offer a light and simple interface to manage the
configuration of your own Python application. It avoids you the burden of
writing the code to build the command line argument parser and/or a
configuration file parser in a self-consistent way.
